==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoadBalancerStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerStrategyBuilder extends LoadBalancerStrategyFluentImpl<LoadBalancerStrategyBuilder> implements VisitableBuilder<LoadBalancerStrategy,LoadBalancerStrategyBuilder>{
  public LoadBalancerStrategyBuilder() {
    this(false);
  }
  public LoadBalancerStrategyBuilder(Boolean validationEnabled) {
    this(new LoadBalancerStrategy(), validationEnabled);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerStrategy(), validationEnabled);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent,LoadBalancerStrategy instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent,LoadBalancerStrategy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withProviderParameters(instance.getProviderParameters());
      fluent.withScope(instance.getScope());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategy instance) {
    this(instance,false);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategy instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withProviderParameters(instance.getProviderParameters());
      this.withScope(instance.getScope());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerStrategyFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerStrategy build() {
    LoadBalancerStrategy buildable = new LoadBalancerStrategy(fluent.getProviderParameters(),fluent.getScope());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoadBalancerStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerStrategyBuilder extends LoadBalancerStrategyFluent<LoadBalancerStrategyBuilder> implements VisitableBuilder<LoadBalancerStrategy,LoadBalancerStrategyBuilder>{
  public LoadBalancerStrategyBuilder() {
    this(false);
  }
  public LoadBalancerStrategyBuilder(Boolean validationEnabled) {
    this(new LoadBalancerStrategy(), validationEnabled);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerStrategy(), validationEnabled);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent,LoadBalancerStrategy instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategyFluent<?> fluent,LoadBalancerStrategy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerStrategy());

    if (instance != null) {
      fluent.withAllowedSourceRanges(instance.getAllowedSourceRanges());
      fluent.withDnsManagementPolicy(instance.getDnsManagementPolicy());
      fluent.withProviderParameters(instance.getProviderParameters());
      fluent.withScope(instance.getScope());
      fluent.withAllowedSourceRanges(instance.getAllowedSourceRanges());
      fluent.withDnsManagementPolicy(instance.getDnsManagementPolicy());
      fluent.withProviderParameters(instance.getProviderParameters());
      fluent.withScope(instance.getScope());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategy instance) {
    this(instance,false);
  }
  public LoadBalancerStrategyBuilder(LoadBalancerStrategy instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerStrategy());

    if (instance != null) {
      this.withAllowedSourceRanges(instance.getAllowedSourceRanges());
      this.withDnsManagementPolicy(instance.getDnsManagementPolicy());
      this.withProviderParameters(instance.getProviderParameters());
      this.withScope(instance.getScope());
      this.withAllowedSourceRanges(instance.getAllowedSourceRanges());
      this.withDnsManagementPolicy(instance.getDnsManagementPolicy());
      this.withProviderParameters(instance.getProviderParameters());
      this.withScope(instance.getScope());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerStrategyFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerStrategy build() {
    LoadBalancerStrategy buildable = new LoadBalancerStrategy(fluent.getAllowedSourceRanges(),fluent.getDnsManagementPolicy(),fluent.buildProviderParameters(),fluent.getScope());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
